==> redshift-0.21.0-sources.jar: software/amazon/awscdk/services/redshift/CfnCluster.java <==
package software.amazon.awscdk.services.redshift;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-cluster.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:28:18.223Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.redshift.$Module.class, fqn = "@aws-cdk/aws-redshift.CfnCluster")
public class CfnCluster extends software.amazon.awscdk.Resource {
    protected CfnCluster(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.redshift.CfnCluster.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Redshift::Cluster``.
     * @param parent the ``cdk.Construct`` this ``CfnCluster`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``CfnCluster``
     */
    public CfnCluster(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.redshift.CfnClusterProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute Endpoint.Address
     */
    public java.lang.String getClusterEndpointAddress() {
        return this.jsiiGet("clusterEndpointAddress", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Endpoint.Port
     */
    public java.lang.String getClusterEndpointPort() {
        return this.jsiiGet("clusterEndpointPort", java.lang.String.class);
    }

    public java.lang.String getClusterName() {
        return this.jsiiGet("clusterName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.redshift.CfnClusterProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.redshift.CfnClusterProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html
     */
    public static interface LoggingPropertiesProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CfnCluster.LoggingPropertiesProperty.BucketName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
         */
        java.lang.Object getBucketName();
        /**
         * ``CfnCluster.LoggingPropertiesProperty.BucketName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
         */
        void setBucketName(final java.lang.String value);
        /**
         * ``CfnCluster.LoggingPropertiesProperty.BucketName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
         */
        void setBucketName(final software.amazon.awscdk.Token value);
        /**
         * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
         */
        java.lang.Object getS3KeyPrefix();
        /**
         * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
         */
        void setS3KeyPrefix(final java.lang.String value);
        /**
         * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
         */
        void setS3KeyPrefix(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link LoggingPropertiesProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link LoggingPropertiesProperty}
         */
        final class Builder {
            private java.lang.Object _bucketName;
            @javax.annotation.Nullable
            private java.lang.Object _s3KeyPrefix;

            /**
             * Sets the value of BucketName
             * @param value ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @return {@code this}
             */
            public Builder withBucketName(final java.lang.String value) {
                this._bucketName = java.util.Objects.requireNonNull(value, "bucketName is required");
                return this;
            }
            /**
             * Sets the value of BucketName
             * @param value ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @return {@code this}
             */
            public Builder withBucketName(final software.amazon.awscdk.Token value) {
                this._bucketName = java.util.Objects.requireNonNull(value, "bucketName is required");
                return this;
            }
            /**
             * Sets the value of S3KeyPrefix
             * @param value ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @return {@code this}
             */
            public Builder withS3KeyPrefix(@javax.annotation.Nullable final java.lang.String value) {
                this._s3KeyPrefix = value;
                return this;
            }
            /**
             * Sets the value of S3KeyPrefix
             * @param value ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @return {@code this}
             */
            public Builder withS3KeyPrefix(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._s3KeyPrefix = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link LoggingPropertiesProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public LoggingPropertiesProperty build() {
                return new LoggingPropertiesProperty() {
                    private java.lang.Object $bucketName = java.util.Objects.requireNonNull(_bucketName, "bucketName is required");
                    @javax.annotation.Nullable
                    private java.lang.Object $s3KeyPrefix = _s3KeyPrefix;

                    @Override
                    public java.lang.Object getBucketName() {
                        return this.$bucketName;
                    }

                    @Override
                    public void setBucketName(final java.lang.String value) {
                        this.$bucketName = java.util.Objects.requireNonNull(value, "bucketName is required");
                    }

                    @Override
                    public void setBucketName(final software.amazon.awscdk.Token value) {
                        this.$bucketName = java.util.Objects.requireNonNull(value, "bucketName is required");
                    }

                    @Override
                    public java.lang.Object getS3KeyPrefix() {
                        return this.$s3KeyPrefix;
                    }

                    @Override
                    public void setS3KeyPrefix(@javax.annotation.Nullable final java.lang.String value) {
                        this.$s3KeyPrefix = value;
                    }

                    @Override
                    public void setS3KeyPrefix(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$s3KeyPrefix = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.CfnCluster.LoggingPropertiesProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
             */
            @Override
            public java.lang.Object getBucketName() {
                return this.jsiiGet("bucketName", java.lang.Object.class);
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
             */
            @Override
            public void setBucketName(final java.lang.String value) {
                this.jsiiSet("bucketName", java.util.Objects.requireNonNull(value, "bucketName is required"));
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
             */
            @Override
            public void setBucketName(final software.amazon.awscdk.Token value) {
                this.jsiiSet("bucketName", java.util.Objects.requireNonNull(value, "bucketName is required"));
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getS3KeyPrefix() {
                return this.jsiiGet("s3KeyPrefix", java.lang.Object.class);
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
             */
            @Override
            public void setS3KeyPrefix(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("s3KeyPrefix", value);
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
             */
            @Override
            public void setS3KeyPrefix(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("s3KeyPrefix", value);
            }
        }
    }
}

==> redshift-0.22.0-sources.jar: software/amazon/awscdk/services/redshift/CfnCluster.java <==
package software.amazon.awscdk.services.redshift;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshift-cluster.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.13 (build 311bf88)", date = "2019-01-11T10:47:01.281Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.redshift.$Module.class, fqn = "@aws-cdk/aws-redshift.CfnCluster")
public class CfnCluster extends software.amazon.awscdk.Resource {
    protected CfnCluster(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.redshift.CfnCluster.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Redshift::Cluster``.
     * @param scope scope in which this resource is defined
     * @param id scoped id of the resource
     * @param props resource properties
     */
    public CfnCluster(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.redshift.CfnClusterProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    /**
     * @cloudformation_attribute Endpoint.Address
     */
    public java.lang.String getClusterEndpointAddress() {
        return this.jsiiGet("clusterEndpointAddress", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute Endpoint.Port
     */
    public java.lang.String getClusterEndpointPort() {
        return this.jsiiGet("clusterEndpointPort", java.lang.String.class);
    }

    public java.lang.String getClusterName() {
        return this.jsiiGet("clusterName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.redshift.CfnClusterProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.redshift.CfnClusterProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html
     */
    public static interface LoggingPropertiesProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``CfnCluster.LoggingPropertiesProperty.BucketName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
         */
        java.lang.String getBucketName();
        /**
         * ``CfnCluster.LoggingPropertiesProperty.BucketName``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
         */
        void setBucketName(final java.lang.String value);
        /**
         * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
         */
        java.lang.String getS3KeyPrefix();
        /**
         * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
         */
        void setS3KeyPrefix(final java.lang.String value);

        /**
         * @return a {@link Builder} of {@link LoggingPropertiesProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link LoggingPropertiesProperty}
         */
        final class Builder {
            private java.lang.String _bucketName;
            @javax.annotation.Nullable
            private java.lang.String _s3KeyPrefix;

            /**
             * Sets the value of BucketName
             * @param value ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @return {@code this}
             */
            public Builder withBucketName(final java.lang.String value) {
                this._bucketName = java.util.Objects.requireNonNull(value, "bucketName is required");
                return this;
            }
            /**
             * Sets the value of S3KeyPrefix
             * @param value ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @return {@code this}
             */
            public Builder withS3KeyPrefix(@javax.annotation.Nullable final java.lang.String value) {
                this._s3KeyPrefix = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link LoggingPropertiesProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public LoggingPropertiesProperty build() {
                return new LoggingPropertiesProperty() {
                    private java.lang.String $bucketName = java.util.Objects.requireNonNull(_bucketName, "bucketName is required");
                    @javax.annotation.Nullable
                    private java.lang.String $s3KeyPrefix = _s3KeyPrefix;

                    @Override
                    public java.lang.String getBucketName() {
                        return this.$bucketName;
                    }

                    @Override
                    public void setBucketName(final java.lang.String value) {
                        this.$bucketName = java.util.Objects.requireNonNull(value, "bucketName is required");
                    }

                    @Override
                    public java.lang.String getS3KeyPrefix() {
                        return this.$s3KeyPrefix;
                    }

                    @Override
                    public void setS3KeyPrefix(@javax.annotation.Nullable final java.lang.String value) {
                        this.$s3KeyPrefix = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.redshift.CfnCluster.LoggingPropertiesProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
             */
            @Override
            public java.lang.String getBucketName() {
                return this.jsiiGet("bucketName", java.lang.String.class);
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.BucketName``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-bucketname
             */
            @Override
            public void setBucketName(final java.lang.String value) {
                this.jsiiSet("bucketName", java.util.Objects.requireNonNull(value, "bucketName is required"));
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.String getS3KeyPrefix() {
                return this.jsiiGet("s3KeyPrefix", java.lang.String.class);
            }

            /**
             * ``CfnCluster.LoggingPropertiesProperty.S3KeyPrefix``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshift-cluster-loggingproperties.html#cfn-redshift-cluster-loggingproperties-s3keyprefix
             */
            @Override
            public void setS3KeyPrefix(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("s3KeyPrefix", value);
            }
        }
    }
}
